@@ -637,7 +637,7 @@ class AsyncPath(Path, AsyncPurePath):
         """Return a new path with expanded ~ and ~user constructs
         (as returned by os.path.expanduser)
         """
-        if not (self._drv or self._root) and self._parts and self._parts[0][:1] == "~":
+        if not self._drv and not self._root and self._parts and self._parts[0][:1] == "~":
             homedir = await self._accessor.expanduser(self._parts[0])
             if homedir[:1] == "~":
                 raise RuntimeError("Could not determine home directory.")
